"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const tool_lib_1 = require("@kettil/tool-lib");
const access_1 = __importDefault(require("../../lib/cmd/access"));
const exec_1 = __importDefault(require("../../lib/cmd/exec"));
const readFile_1 = __importDefault(require("../../lib/cmd/readFile"));
const writeFile_1 = __importDefault(require("../../lib/cmd/writeFile"));
const npmInit = async ({ cwd, log }, { packageBin, packageInit, packageScripts, packageUpdate }) => {
    const path = path_1.join(cwd, 'package.json');
    const isExists = await access_1.default(path);
    if (!isExists) {
        log.info('Initialize the package.json');
        await exec_1.default({ cmd: 'npm', args: ['init', '-y'], cwd, log });
    }
    else {
        log.info('package.json already exists');
    }
    const config = await readFile_1.default(path, true);
    // Update only first run
    if (!isExists) {
        Object.assign(config, packageInit);
        if (Object.keys(packageBin).length > 0) {
            config.bin = Object.assign(tool_lib_1.isObject(config.bin) ? config.bin : {}, packageBin);
        }
    }
    // Update every run
    Object.assign(config, packageUpdate);
    // Update the scripts part; every run
    config.scripts = Object.assign(tool_lib_1.isObject(config.scripts) ? config.scripts : {}, packageScripts);
    log.info('Extend the package.json');
    await writeFile_1.default(path, config);
};
exports.default = npmInit;
